==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexportertoolchain.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERTOOLCHAIN_H
#define BIBTEXBIBTEXFILEEXPORTERTOOLCHAIN_H

#include <bibtexfileexporter.h>

class QString;
class QWaitCondition;
class QProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterToolchain : public BibTeXFileExporter
    {
        Q_OBJECT
    public:
        BibTeXFileExporterToolchain();
        ~BibTeXFileExporterToolchain();

    public slots:
        void cancel();

    protected:
        QString workingDir;

        bool runProcesses( const QStringList &progs );
        bool runProcess( const QStringList &args );
        bool writeFileToIODevice( const QString &filename, QIODevice *device );

    private:
        QWaitCondition *wc;
        QProcess *process;

        QString createTempDir();
        void deleteTempDir( const QString& directory );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();

    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexportertoolchain.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERTOOLCHAIN_H
#define BIBTEXBIBTEXFILEEXPORTERTOOLCHAIN_H

#include <bibtexfileexporter.h>

class QString;
class QWaitCondition;
class QProcess;
class QStringList;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterToolchain : public BibTeXFileExporter
    {
        Q_OBJECT
    public:
        BibTeXFileExporterToolchain();
        ~BibTeXFileExporterToolchain();

    public slots:
        void cancel();

    protected:
        QString workingDir;

        bool runProcesses( const QStringList &progs, QStringList *errorLog = NULL );
        bool runProcess( const QStringList &args, QStringList *errorLog = NULL );
        bool writeFileToIODevice( const QString &filename, QIODevice *device );

    private:
        QWaitCondition *wc;
        QProcess *process;
        QStringList *m_errorLog;

        QString createTempDir();
        void deleteTempDir( const QString& directory );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();

    };

}

#endif
